@@ -42,10 +42,10 @@ class HonCommand:
         return await self._connector.send_command(self._device, self._name, self.parameters,
                                                   self.ancillary_parameters)
 
-    async def get_programs(self):
+    def get_programs(self):
         return self._multi
 
-    async def set_program(self, program):
+    def set_program(self, program):
         self._device.commands[self._name] = self._multi[program]
 
     def _get_settings_keys(self, command=None):
