@@ -97,7 +97,7 @@ class HonParameterProgram(HonParameterEnum):
         super().__init__(key, {})
         self._command = command
         self._value = command._category
-        self._values = list(command._multi)
+        self._values = command._multi
 
     @property
     def value(self):
